@@ -1,4 +1,4 @@
-if [ ! -f /etc/vimrc ]
+if [ ! -e /etc/vimrc ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/vimrc /etc/vimrc
